import premierlibrary from 'libpremierlibrary.so';
import { Log } from '../../utils/Log';
import { Option, AudioStatus, } from '../IPlayer';
import { InfoBean } from '../bean/InfoBean';
import { findInfoCodeByValue, InfoCode } from '../bean/InfoCode';
import { findErrorCodeByValue } from '../bean/PlayerErrorCode';
import { ErrorInfo } from '../bean/ErrorInfo';
import { ObjCreateHelper } from '../../utils/ObjCreateHelper';
const log = new Log('NativePlayerBase');
export class NativePlayerBase {
    constructor(d26) {
        this.mNativeContext = 0;
        this.objHelper = new ObjCreateHelper();
        this.getNativeContext = () => {
            log.info(`getNativeContext, address: ${this.mNativeContext}`);
            return this.mNativeContext;
        };
        this.setNativeContext = (p29) => {
            log.info(`setNativeContext, address: ${p29}`);
            this.mNativeContext = p29;
        };
        this.getHelper = () => {
            log.info(`getHelper`);
            return this.objHelper;
        };
        this.getContext = () => {
            log.info(`getNativeContext, address: ${this.mNativeContext}`);
            return this.mContext;
        };
        this.onPrepared = () => {
            console.log('onPrepared called at nativePlayerBase.');
            if (this.mOnPreparedListener != null) {
                this.mOnPreparedListener.onPrepared();
            }
        };
        this.onCircleStart = () => {
            if (this.mOnInfoListener != null) {
                let o29 = new InfoBean();
                o29.setCode(InfoCode.LoopingStart);
                this.mOnInfoListener.onInfo(o29);
            }
        };
        this.onAutoPlayStart = () => {
            if (this.mOnInfoListener != null) {
                let n29 = new InfoBean();
                n29.setCode(InfoCode.AutoPlayStart);
                this.mOnInfoListener.onInfo(n29);
            }
        };
        this.onEvent = (j29, k29) => {
            if (this.mOnInfoListener != null) {
                let l29 = findInfoCodeByValue(j29);
                let m29 = new InfoBean();
                m29.setCode(l29);
                m29.setExtraMsg(k29);
                this.mOnInfoListener.onInfo(m29);
            }
        };
        this.onCurrentDownloadSpeed = (h29) => {
            if (this.mOnInfoListener != null) {
                let i29 = new InfoBean();
                i29.setCode(InfoCode.CurrentDownloadSpeed);
                i29.setExtraValue(h29);
                this.mOnInfoListener.onInfo(i29);
            }
        };
        this.onUtcTimeUpdate = (f29) => {
            if (this.mOnInfoListener != null) {
                let g29 = new InfoBean();
                g29.setCode(InfoCode.UtcTime);
                g29.setExtraValue(f29);
                this.mOnInfoListener.onInfo(g29);
            }
        };
        this.onLocalCacheLoad = (d29) => {
            if (this.mOnInfoListener != null) {
                let e29 = new InfoBean();
                e29.setCode(InfoCode.LocalCacheLoaded);
                e29.setExtraValue(d29);
                this.mOnInfoListener.onInfo(e29);
            }
        };
        this.onBufferedPositionUpdate = (b29) => {
            if (this.mOnInfoListener != null) {
                let c29 = new InfoBean();
                c29.setCode(InfoCode.BufferedPosition);
                c29.setExtraValue(b29);
                this.mOnInfoListener.onInfo(c29);
            }
        };
        this.onCurrentPositionUpdate = (z28) => {
            if (this.mOnInfoListener != null) {
                let a29 = new InfoBean();
                a29.setCode(InfoCode.CurrentPosition);
                a29.setExtraValue(z28);
                this.mOnInfoListener.onInfo(a29);
            }
        };
        this.onFirstFrameShow = () => {
            if (this.mOnRenderingStartListener != null) {
                this.mOnRenderingStartListener.onRenderingStart();
            }
        };
        this.onVideoSizeChanged = (x28, y28) => {
            if (this.mOnVideoSizeChangedListener != null) {
                this.mOnVideoSizeChangedListener.onVideoSizeChanged(x28, y28);
            }
        };
        this.onAudioInterruptEvent = (w28) => {
            if (this.mOnAudioInterruptEventListener != null) {
                if (w28 < AudioStatus.AUDIO_STATUS_DEFAULT || w28 > AudioStatus.AUDIO_STATUS_UNDUCK) {
                    log.info('onAudioInterruptEvent exception audioStatus: ' + w28);
                    this.mOnAudioInterruptEventListener.onAudioInterruptEvent(AudioStatus.AUDIO_STATUS_DEFAULT);
                    return;
                }
                this.mOnAudioInterruptEventListener.onAudioInterruptEvent(w28);
            }
        };
        this.onLoadingStart = () => {
            if (this.mOnLoadingStatusListener != null) {
                this.mOnLoadingStatusListener.onLoadingBegin();
            }
        };
        this.onLoadingProgress = (v28) => {
            if (this.mOnLoadingStatusListener != null) {
                this.mOnLoadingStatusListener.onLoadingProgress(v28, 0);
            }
        };
        this.onLoadingEnd = () => {
            if (this.mOnLoadingStatusListener != null) {
                this.mOnLoadingStatusListener.onLoadingEnd();
            }
        };
        this.onAVNotSyncStart = (u28) => {
            if (this.mOnAVNotSyncStatusListener != null) {
                this.mOnAVNotSyncStatusListener.onAVNotSyncStart(u28);
            }
        };
        this.onAVNotSyncEnd = (t28) => {
            if (this.mOnAVNotSyncStatusListener != null) {
                this.mOnAVNotSyncStatusListener.onAVNotSyncEnd();
            }
        };
        this.onSeekEnd = () => {
            if (this.mOnSeekCompleteListener != null) {
                this.mOnSeekCompleteListener.onSeekComplete();
            }
        };
        this.onStatusChanged = (r28, s28) => {
            log.info('onStatusChanged, newState: ' + r28 + ' oldState: ' + s28);
            if (this.mOnStateChangedListener != null) {
                this.mOnStateChangedListener.onStateChanged(r28);
            }
        };
        this.onCompletion = () => {
            if (this.mOnCompletionListener != null) {
                this.mOnCompletionListener.onCompletion();
            }
        };
        this.onVideoRendered = (p28, q28) => {
            if (this.mOnVideoRenderedListener != null) {
                this.mOnVideoRenderedListener.onVideoRendered(p28, q28);
            }
        };
        this.onShowSubtitle = (m28, n28, o28) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleShow(m28, n28, o28);
            }
        };
        this.onSubtitleExtAdded = (k28, l28) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleExtAdded(k28, l28);
            }
        };
        this.onHideSubtitle = (i28, j28) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleHide(i28, j28);
            }
        };
        this.onSubtitleHeader = (g28, h28) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleHeader(g28, h28);
            }
        };
        this.onError = (b28, c28, d28) => {
            let e28 = findErrorCodeByValue(b28);
            if (this.mOnErrorListener != null) {
                let f28 = new ErrorInfo();
                f28.setCode(e28);
                f28.setMsg(c28);
                f28.setExtra(d28);
                this.mOnErrorListener.onError(f28);
            }
        };
        this.onStreamSwitchSuc = (a28) => {
            if (this.mOnTrackChangedListener != null) {
                this.mOnTrackChangedListener.onChangedSuccess(a28);
            }
        };
        this.onStreamInfoGet = (z27) => {
            if (this.mOnTrackReadyListener != null) {
                this.mOnTrackReadyListener.onTrackReady(z27);
            }
        };
        this.onSubStreamInfoGet = (y27) => {
            if (this.mOnSubTrackReadyListener != null) {
                this.mOnSubTrackReadyListener.onSubTrackReady(y27);
            }
        };
        this.onSwitchStreamUrlResult = (t27, u27, v27) => {
            if (this.mOnStreamSwitchedListener == null) {
                return;
            }
            if (u27 == 0) {
                this.mOnStreamSwitchedListener.onSwitchedSuccess(t27);
            }
            else {
                let w27 = findErrorCodeByValue(u27);
                let x27 = new ErrorInfo();
                x27.setCode(w27);
                x27.setMsg(v27);
                this.mOnStreamSwitchedListener.onSwitchedFail(t27, x27);
            }
        };
        this.onCaptureScreen = (q27, r27, s27) => {
            if (this.mOnSnapShotListener != null) {
                this.mOnSnapShotListener.onSnapShot(s27, q27, r27);
            }
        };
        this.onSeiDataCallback = (o27, p27) => {
            if (this.mOnSeiDataListener != null) {
                this.mOnSeiDataListener.onSeiData(o27, new Uint8Array(p27));
            }
        };
        log.info('constructor_');
        this.mContext = d26;
        premierlibrary.nConstruct(this);
    }
    setOnPreparedListener(c26) {
        this.mOnPreparedListener = c26;
    }
    setOnInfoListener(b26) {
        this.mOnInfoListener = b26;
    }
    setOnRenderingStartListener(a26) {
        this.mOnRenderingStartListener = a26;
    }
    setOnStateChangedListener(z25) {
        this.mOnStateChangedListener = z25;
    }
    setOnCompletionListener(y25) {
        this.mOnCompletionListener = y25;
    }
    setOnLoadingStatusListener(x25) {
        this.mOnLoadingStatusListener = x25;
    }
    setOnErrorListener(w25) {
        this.mOnErrorListener = w25;
    }
    setOnVideoSizeChangedListener(v25) {
        this.mOnVideoSizeChangedListener = v25;
    }
    setOnSeekCompleteListener(u25) {
        this.mOnSeekCompleteListener = u25;
    }
    setOnSubtitleDisplayListener(t25) {
        this.mOnSubtitleDisplayListener = t25;
    }
    setOnVideoRenderedListener(s25) {
        this.mOnVideoRenderedListener = s25;
    }
    setOnAudioInterruptEventListener(r25) {
        this.mOnAudioInterruptEventListener = r25;
    }
    setOnTrackReadyListener(q25) {
        this.mOnTrackReadyListener = q25;
    }
    setOnSubTrackReadyListener(p25) {
        this.mOnSubTrackReadyListener = p25;
    }
    setOnStreamSwitchedListener(o25) {
        this.mOnStreamSwitchedListener = o25;
    }
    setOnAVNotSyncStatusListener(n25) {
        this.mOnAVNotSyncStatusListener = n25;
    }
    setOnTrackChangedListener(m25) {
        this.mOnTrackChangedListener = m25;
    }
    setOnSnapShotListener(l25) {
        this.mOnSnapShotListener = l25;
    }
    setOnSeiDataListener(k25) {
        this.mOnSeiDataListener = k25;
    }
    start() {
        log.info('nStart');
        premierlibrary.nStart(this);
    }
    pause() {
        log.info('nPause');
        premierlibrary.nPause(this);
    }
    stop() {
        log.info('nStop');
        premierlibrary.nStop(this);
    }
    prepare() {
        log.info('nPrepare');
        premierlibrary.nPrepare(this);
    }
    setAutoPlay(j25) {
        log.info('nPrepare');
        premierlibrary.nSetAutoPlay(this, j25);
    }
    setSurfaceId(i25) {
        log.info('nSetSurfaceId');
        premierlibrary.nSetSurfaceId(this, i25);
    }
    setSpeed(h25) {
        log.info('setSpeed');
        premierlibrary.nSetSpeed(this, h25);
    }
    switchStream(g25) {
        log.info('switchStream');
        premierlibrary.nSwitchStream(this, g25);
    }
    setAlphaRenderMode(f25) {
        log.info('setAlphaRenderMode');
        premierlibrary.nSetAlphaRenderMode(this, f25);
    }
    getAlphaRenderMode() {
        log.info('getAlphaRenderMode');
        return premierlibrary.nGetAlphaRenderMode(this);
    }
    selectTrack(e25) {
        log.info('selectTrack');
        premierlibrary.nSelectTrack(this, e25);
    }
    getCurrentTrack(c25) {
        log.info('getCurrentTrack, type: ' + c25);
        let d25 = premierlibrary.nGetCurrentStreamInfo(this, c25);
        return d25;
    }
    addExtSubtitle(b25) {
        log.info(`addExtSubtitle`);
        premierlibrary.nAddExtSubtitle(this, b25);
    }
    selectExtSubtitle(z24, a25) {
        log.info(`selectExtSubtitle`);
        premierlibrary.nSelectExtSubtitle(this, z24, a25);
    }
    setVolume(y24) {
        log.info('setVolume');
        premierlibrary.nSetVolume(this, y24);
    }
    getVolume() {
        log.info('getVolume');
        return premierlibrary.nGetVolume(this);
    }
    seekTo(w24, x24) {
        log.info('seekTo');
        premierlibrary.nSeekTo(this, w24, x24);
    }
    setStartTime(u24, v24) {
        log.info('setStartTime');
        premierlibrary.nSetStartTime(this, u24, v24);
    }
    getDuration() {
        log.info('getDuration');
        return premierlibrary.nGetDuration(this);
    }
    getPlayedDuration() {
        log.info('getPlayedDuration');
        return premierlibrary.nGetPlayedDuration(this);
    }
    getCurrentPosition() {
        log.info('getCurrentPosition');
        return premierlibrary.nGetCurrentPosition(this);
    }
    getBufferedPosition() {
        log.info('getBufferedPosition');
        return premierlibrary.nGetBufferedPosition(this);
    }
    getPlayerStatus() {
        log.info('getPlayerStatus');
        return premierlibrary.nGetPlayerStatus(this);
    }
    setTraceId(t24) {
        log.info('setTraceId');
        premierlibrary.nSetTraceId(this, t24);
    }
    enableHardwareDecoder(s24) {
        log.info('enableHardwareDecoder');
        premierlibrary.nEnableHardwareDecoder(this, s24);
    }
    release() {
        log.info('release');
        premierlibrary.nRelease(this);
    }
    setMute(r24) {
        log.info('setMute');
        premierlibrary.nSetMute(this, r24);
    }
    isMuted() {
        log.info('isMuted');
        return premierlibrary.nIsMuted(this) === 1;
    }
    setScaleMode(q24) {
        log.info('setScaleMode');
        premierlibrary.nSetScaleMode(this, q24);
    }
    getScaleMode() {
        log.info('getScaleMode');
        return premierlibrary.nGetScaleMode(this);
    }
    setLoop(p24) {
        log.info('setLoop');
        premierlibrary.nSetLoop(this, p24);
    }
    isLoop() {
        log.info('isLoop');
        return premierlibrary.nIsLoop(this) === 1;
    }
    getVideoWidth() {
        log.info('getVideoWidth');
        return premierlibrary.nGetVideoWidth(this);
    }
    getVideoHeight() {
        log.info('getVideoHeight');
        return premierlibrary.nGetVideoHeight(this);
    }
    getVideoRotation() {
        log.info('getVideoRotation');
        return premierlibrary.nGetVideoRotation(this);
    }
    reload() {
        log.info('reload');
        premierlibrary.nReload(this);
    }
    setRotateMode(o24) {
        log.info('setRotateMode');
        premierlibrary.nSetRotateMode(this, o24);
    }
    getRotateMode() {
        log.info('getRotateMode');
        return premierlibrary.nGetRotateMode(this);
    }
    setMirrorMode(n24) {
        log.info('setMirrorMode');
        premierlibrary.nSetMirrorMode(this, n24);
    }
    getMirrorMode() {
        log.info('getMirrorMode');
        return premierlibrary.nGetMirrorMode(this);
    }
    setVideoBackgroundColor(m24) {
        log.info('setVideoBackgroundColor');
        premierlibrary.nSetVideoBackgroundColor(this, m24);
    }
    getSpeed() {
        log.info('getSpeed');
        return premierlibrary.nGetSpeed(this);
    }
    isAutoPlay() {
        log.info('isAutoPlay');
        return premierlibrary.nIsAutoPlay(this) === 1;
    }
    setConfig(l24) {
        log.info('setConfig');
        premierlibrary.nSetConfig(this, l24);
        this.mPlayerConfig = l24;
    }
    getConfig() {
        log.info('getConfig');
        let k24 = premierlibrary.nGetConfig(this);
        return k24;
    }
    setOption(i24, j24) {
        log.info('setOption');
        premierlibrary.nSetOption(this, i24, j24);
    }
    getOption(f24) {
        let g24 = premierlibrary.nGetOption(this, f24);
        if (f24 == Option.RenderFPS ||
            f24 == Option.DownloadBitrate ||
            f24 == Option.VideoBitrate ||
            f24 == Option.AudioBitrate) {
            let h24 = parseFloat(g24);
            return h24;
        }
        return g24;
    }
    setStreamDelay(d24, e24) {
        log.info('setStreamDelay');
        premierlibrary.nSetStreamDelay(this, d24, e24);
    }
    setMaxAccurateSeekDelta(c24) {
        log.info('setMaxAccurateSeekDelta');
        premierlibrary.nSetMaxAccurateSeekDelta(this, c24);
    }
    setCacheConfig(b24) {
        log.info('setCacheConfig');
        premierlibrary.nSetCacheConfig(this, b24);
    }
    setIPResolveType(a24) {
        log.info('setIPResolveType');
        premierlibrary.nSetIPResolveType(this, a24);
    }
    setFastStart(z23) {
        log.info('setFastStart');
        premierlibrary.nSetFastStart(this, z23);
    }
    snapShot() {
        log.info('snapShot');
        premierlibrary.nSnapShot(this);
    }
    clearScreen() {
        log.info('clearScreen');
        premierlibrary.nClearScreen(this);
    }
    getSdkVersion() {
        log.info('getSdkVersion');
        return premierlibrary.nGetSdkVersion();
    }
    getCacheFilePathByUrl(y23) {
        log.info('getCacheFilePathByUrl');
        return premierlibrary.nGetCacheFilePathByUrl(this, y23);
    }
    getCacheFilePathByVid(u23, v23, w23, x23) {
        log.info('getCacheFilePathByVid');
        return premierlibrary.nGetCacheFilePathByVid(this, u23, v23, w23, x23);
    }
    getPropertyString(t23) {
        log.info('getPropertyString');
        return premierlibrary.nGetPropertyString(this, t23);
    }
    setDefaultBandWidth(s23) {
        log.info('setDefaultBandWidth');
        premierlibrary.nSetDefaultBandWidth(this, s23);
    }
    sendCustomEvent(r23) {
        log.info('sendCustomEvent');
        premierlibrary.nSendCustomEvent(this, r23);
    }
    setVideoTag(q23) {
        log.info('setVideoTag');
        premierlibrary.nSetVideoTag(this, q23);
    }
    setUserData(p23) {
        log.info('setUserData');
        premierlibrary.nSetUserData(this, p23);
    }
    getUserData() {
        log.info('getUserData');
        return premierlibrary.nGetUserData(this);
    }
    getNativeContextAddr() {
        return this.mNativeContext;
    }
}
